@@ -4,14 +4,13 @@ from beta9.abstractions.endpoint import Endpoint as endpoint
 from beta9.abstractions.function import Function as function
 from beta9.abstractions.image import Image
 from beta9.abstractions.map import Map
+from beta9.abstractions.output import Output
 from beta9.abstractions.queue import SimpleQueue as Queue
 from beta9.abstractions.taskqueue import TaskQueue as task_queue
 from beta9.abstractions.volume import Volume
 from beta9.type import GpuType, PythonVersion
 
-__version__ = "0.2.9"
 __all__ = [
-    "__version__",
     "Map",
     "Image",
     "Queue",
@@ -23,4 +22,5 @@ __all__ = [
     "env",
     "PythonVersion",
     "GpuType",
+    "Output",
 ]
