@@ -4,6 +4,8 @@ from pathlib import Path
 from beta9.cli.main import load_cli
 from beta9.config import SDKSettings
 
+from . import configure, login, quickstart
+
 settings = SDKSettings(
     name="Beam",
     api_host=os.getenv("API_HOST", "https://app.beam.cloud"),
@@ -14,3 +16,7 @@ settings = SDKSettings(
 
 
 cli = load_cli(settings=settings)
+cli.register(configure)
+cli.register(quickstart)
+cli.register(login)
+cli.load_version("beam-client")
